/*====================================+=====================================+
! File CApp.h                         ! Copyright (C) 2018-2019 Remi PASCAL !
+-------------------------------------+-------------------------------------+
! This file is part of kimfo.                                               !
! It is free software: you can redistribute it and/or modify it under the   !
! terms of the GNU General Public License as published by the Free Software !
! Foundation, either version 3 of the License, or any later version.        !
! This application is distributed in the hope that it will be useful, but   !
! WITHOUT ANY WARRANTY; without even the implied warranty of                !
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General !
! Public License for more details.                                          !
! You should have received a copy of the GNU General Public License along   !
! with this application. If not, see <http://www.gnu.org/licenses/>.        !
+==========================================================================*/



/*-------------------------------------------------------------------------*/
#pragma once
/*-------------------------------------------------------------------------*/
#include <wx/cmdline.h>
#include <wx/app.h>
#include <wx/filename.h>
#include <wx/snglinst.h>
#include "common/sc_base.h"
#include "common/sc_config.h"
/*-------------------------------------------------------------------------*/
class CFrame ;
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
class CApp : public wxApp
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      ~CApp() ;

   /*----------------------------------------------------------------------*/
   private :
      /*-------------------------------------------------------------------*/
      bool       m_boo_first_start_ever = false ; // Program never started ?
      wxFileName m_fn_exe ; // Current executable
      wxLocale   m_locale ; // Default main locale object
      wxString   m_s_program_to_start_on_exit ;
      /*-------------------------------------------------------------------*/
      wxSingleInstanceChecker *m_sins_checker = nullptr ;
      sc::CSIServer *m_sins_server = nullptr ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CFrame *m_frame = nullptr ;

   /*----------------------------------------------------------------------*/
   public :
      /*--------------------------------------------------------------------+
      ! Serialized member variables : the "m" is upper-case                 !
      +--------------------------------------------------------------------*/
      CConfigRect   M_rec_main ;
      CConfigRect   M_rec_prefs ;
      CConfigRect   M_rec_progress ;
      CConfigRect   M_rec_lastversion ;
      CConfigRect   M_rec_newversion ;
      /*-------------------------------------------------------------------*/
      CConfigInt    M_i_spl_hor_pos ; // Horizontal splitter position
      /*-------------------------------------------------------------------*/
      CConfigString M_s_lang ; // Canonical name: en_US ...
      CConfigString M_s_region ; // Region code : see
      CConfigInt    M_i_chkupd_freq ;
      CConfigString M_s_chkupd_last ; // YYYY-MM-DD (ISO)
      CConfigBool   M_boo_startup_auto_check_avail ;
      CConfigBool   M_boo_startup_systray_only ;
      CConfigInt    M_i_check_avail_period ;
      CConfigString M_s_proxy_server ;
      CConfigString M_s_serv_ref_sel ; // Selected server references
      CConfigString M_s_serv_list_col_width ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      virtual bool OnInit() override ;
      virtual void OnInitCmdLine( wxCmdLineParser &parser ) override ;
      virtual bool OnCmdLineParsed( wxCmdLineParser &parser ) override ;
      /*-------------------------------------------------------------------*/
      bool get_first_start_ever() const
      {  return m_boo_first_start_ever ; }
      int actions_for_install_process() ;
      wxString get_exe_path() const { return m_fn_exe.GetPath() ; }
      wxString get_exe_fullpath() const { return m_fn_exe.GetFullPath() ; }
      wxString get_exe_fullname() const { return m_fn_exe.GetFullName() ; }
      /*-------------------------------------------------------------------*/
      const wxString &get_program_to_start_on_exit() const
      {  return m_s_program_to_start_on_exit ; }
      void set_program_to_start_on_exit( const wxString &s_program )
      {  m_s_program_to_start_on_exit = s_program ; }
      void restart_on_exit()
      {  m_s_program_to_start_on_exit = get_exe_fullpath() ; }
      void no_start_on_exit()
      {  m_s_program_to_start_on_exit.clear() ; }
      /*-------------------------------------------------------------------*/
      wxString get_canonical_name() const
      {  return m_locale.GetCanonicalName() ; }
      void init_translations( const wxString &s_canonical_name
                                           = wxEmptyString
                            ) ;
      void init_config_info_to_keep() ;
      void open_config_file( const wxString &s_file, const int i_version ) ;
      void init_config_info() ;
      void save_config_info() ;
      /*-------------------------------------------------------------------*/
      int single_instance() ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
DECLARE_APP( CApp )
/*-------------------------------------------------------------------------*/



/*==========================================================================+
!                            End of file CApp.h                             !
+==========================================================================*/
