/*====================================+=====================================+
! File CDlgPrefs.h                    ! Copyright (C) 2018-2019 Remi PASCAL !
+-------------------------------------+-------------------------------------+
! This file is part of kimfo.                                               !
! It is free software: you can redistribute it and/or modify it under the   !
! terms of the GNU General Public License as published by the Free Software !
! Foundation, either version 3 of the License, or any later version.        !
! This application is distributed in the hope that it will be useful, but   !
! WITHOUT ANY WARRANTY; without even the implied warranty of                !
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General !
! Public License for more details.                                          !
! You should have received a copy of the GNU General Public License along   !
! with this application. If not, see <http://www.gnu.org/licenses/>.        !
+==========================================================================*/



/*-------------------------------------------------------------------------*/
#pragma once
/*-------------------------------------------------------------------------*/
#include <wx/bookctrl.h>
#include <wx/propdlg.h>
#include <wx/spinctrl.h>
#include <wx/radiobox.h>
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
class CDlgPrefs ;
/*-------------------------------------------------------------------------*/



/*--------------------------------------------------------------------------+
! Possible operations to do after a validation (apply/ok )                  !
! They can be ORed. PPA stands for Post Preferences Action                  !
+--------------------------------------------------------------------------*/
enum e_post_prefs_actions { PPA_NOTHING              = 0,
                            PPA_RELOAD_SERVER_LIST   = 1 << 1,
                            PPA_RESTART_AUTO_REFRESH = 1 << 2,
                            PPA_RESTART              = 1 << 3
                          } ;

/*-------------------------------------------------------------------------*/
class CPanPrefs : public wxPanel
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPanPrefs( wxWindow *parent, CDlgPrefs *dlg )
               : wxPanel( parent ), m_dlg( dlg )
      {  ; }

   /*----------------------------------------------------------------------*/
   protected :
      /*-------------------------------------------------------------------*/
      CDlgPrefs *m_dlg ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      virtual void init_default() = 0 ;
      virtual void apply_changes( wxUint32 &ui32_ppa ) = 0 ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CPanPrefsGen : public CPanPrefs
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPanPrefsGen( wxWindow *parent, CDlgPrefs *dlg ) ;

   /*----------------------------------------------------------------------*/
   private :
      /*-------------------------------------------------------------------*/
      wxChoice     *m_cho_lang                     = nullptr ;
      wxChoice     *m_cho_chkupd_freq              = nullptr ;
      wxStaticText *m_stx_chkupd_next              = nullptr ;
      wxChoice     *m_cho_region                   = nullptr ;
      wxCheckBox   *m_chk_startup_auto_check_avail = nullptr ;
      wxCheckBox   *m_chk_startup_systray_only     = nullptr ;
      wxSpinCtrl   *m_i_check_avail_period         = nullptr ;
      wxStaticText *m_stx_check_avail_period_hms   = nullptr ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      void build_ui() ;
      /*-------------------------------------------------------------------*/
      virtual void init_default() override ;
      virtual void apply_changes( wxUint32 &ui32_ppa ) override ;
      /*-------------------------------------------------------------------*/
      void append_cho_lang( const wxString &s_desc,
                            const wxString &s_canon
                          ) ;
      wxString get_cho_lang_sel_canon() ;
      void init_cho_lang() ;
      void init_chkupd_next() ;
      wxString get_cho_region_sel() ;
      void append_cho_region( const wxString &s_name,
                              const wxString &s_region
                            ) ;
      void init_cho_region() ;
      void init_period_hms() ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CPanPrefsNet : public CPanPrefs
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CPanPrefsNet( wxWindow *parent, CDlgPrefs *dlg ) ;

   /*----------------------------------------------------------------------*/
   private :
      /*-------------------------------------------------------------------*/
      wxTextCtrl *m_txt_proxy_server ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      void build_ui() ;
      /*-------------------------------------------------------------------*/
      virtual void init_default() ;
      virtual void apply_changes( wxUint32 &ui32_ppa ) ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/
class CDlgPrefs : public wxPropertySheetDialog
{
   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      CDlgPrefs() ;
      ~CDlgPrefs() ;

   /*----------------------------------------------------------------------*/
   private :
      /*--( Restart needed after preference modification )-----------------*/
      bool m_boo_restart = false ;

   /*----------------------------------------------------------------------*/
   public :
      /*-------------------------------------------------------------------*/
      void OnBtOk( wxCommandEvent &event )
      {  apply_changes() ; EndModal( event.GetId() ) ; }
      void OnBtApply( wxCommandEvent &event )
      {  apply_changes() ; }
      void OnBtResetPage( wxCommandEvent &event )
      {  get_current_page()->init_default() ; }
      /*-------------------------------------------------------------------*/
      size_t get_nb_page() const
      {  return GetBookCtrl()->GetPageCount() ; }
      /*-------------------------------------------------------------------*/
      CPanPrefs *get_page( size_t sz_num )
      {  return static_cast<CPanPrefs *>( GetBookCtrl()->GetPage( sz_num ));}
      /*-------------------------------------------------------------------*/
      CPanPrefs *get_current_page()
      {  return get_page( GetBookCtrl()->GetSelection() ) ; }
      /*-------------------------------------------------------------------*/
      void build_ui() ;
      void apply_changes() ;
      int get_modal() ;

   /*----------------------------------------------------------------------*/
} ;

/*-------------------------------------------------------------------------*/



/*==========================================================================+
!                          End of file CDlgPrefs.h                          !
+==========================================================================*/
