/*====================================+=====================================+
! File sc_about.cpp                   ! Copyright (C) 2018-2019 Remi PASCAL !
+-------------------------------------+-------------------------------------+
! This is free software: you can redistribute it and/or modify it under the !
! terms of the GNU General Public License as published by the Free Software !
! Foundation, either version 3 of the License, or any later version.        !
! This application is distributed in the hope that it will be useful, but   !
! WITHOUT ANY WARRANTY; without even the implied warranty of                !
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General !
! Public License for more details.                                          !
! You should have received a copy of the GNU General Public License along   !
! with this application. If not, see <http://www.gnu.org/licenses/>.        !
+==========================================================================*/



/*-------------------------------------------------------------------------*/
#include <wx/hyperlink.h>
#include <wx/wrapsizer.h>
#include "CApp.h"
#include "CFrame.h"
#include "CDlgAbout.h"
#include "app_info.h"
#include "app_64x64.xpm"
/*-------------------------------------------------------------------------*/



/*--( Border flags )-------------------------------------------------------*/
const int st_co_i_bf = wxLEFT | wxRIGHT | wxBOTTOM ;


/*-------------------------------------------------------------------------*/
sc::CDlgAboutBase::CDlgAboutBase( wxWindow *parent )
                 : wxDialog( parent, wxID_ANY,
                             wxGetStockLabel( wxID_ABOUT, wxSTOCK_NOFLAGS )
                           )
{  ; }

/*-------------------------------------------------------------------------*/
void sc::CDlgAboutBase::add_credit_url( const wxString &s_label,
                                        const wxString &s_url
                                      )
{
   /*----------------------------------------------------------------------*/
   wxGenericHyperlinkCtrl *hl
             = new wxGenericHyperlinkCtrl( this, wxID_ANY, s_label, s_url ) ;
   /*----------------------------------------------------------------------*/
   m_wsz_credits->Add( hl, 0, wxALIGN_CENTER_VERTICAL | st_co_i_bf, 5 ) ;
   /*----------------------------------------------------------------------*/
}

/*-------------------------------------------------------------------------*/
void sc::CDlgAboutBase::add_credit( const wxString &s_label )
{
   /*----------------------------------------------------------------------*/
   m_wsz_credits->Add( new wxStaticText( this, wxID_ANY, s_label ),
                       0, wxALIGN_CENTER_VERTICAL | st_co_i_bf, 5
                     ) ;
   /*----------------------------------------------------------------------*/
}

/*-------------------------------------------------------------------------*/
void sc::CDlgAboutBase::add_credit_wx()
{
   /*----------------------------------------------------------------------*/
   add_credit_url( "wxWidgets", "www.wxwidgets.org" ) ;
   add_credit_url( "Code::Blocks", "codeblocks.org" ) ;
   add_credit_url( "Poedit", "poedit.net" ) ;
   /*----------------------------------------------------------------------*/
}

/*-------------------------------------------------------------------------*/
void sc::CDlgAboutBase::add_credit_tango()
{
   /*----------------------------------------------------------------------*/
   add_credit_url( "Tango Desktop Project", "tango.freedesktop.org" ) ;
   /*----------------------------------------------------------------------*/
}

/*-------------------------------------------------------------------------*/
void sc::CDlgAboutBase::add_credit_libcurl()
{
   /*----------------------------------------------------------------------*/
   add_credit_url( "libcurl", "curl.haxx.se/libcurl" ) ;
   /*----------------------------------------------------------------------*/
}

/*-------------------------------------------------------------------------*/
void sc::CDlgAboutBase::build_ui()
{
   /*----------------------------------------------------------------------*/
   const wxString co_s_version(   APP_VERSION " ("
                                + wxGetTranslation( APP_BITNESS_TEXT )
                                + ")"
                              ) ;
   /*--( Build UI )--------------------------------------------------------*/
   wxBoxSizer *bsz_gen = new wxBoxSizer( wxVERTICAL ) ;
   wxBoxSizer *bsz_icon_ident = new wxBoxSizer( wxHORIZONTAL ) ;

   /*--( Icon )------------------------------------------------------------*/
   wxStaticBitmap *stb_icon
   = new wxStaticBitmap( this, wxID_ANY, wxBitmap( app_64x64_xpm ) ) ;
   bsz_icon_ident->Add( stb_icon, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5 ) ;

   /*--( Identification )--------------------------------------------------*/
   wxBoxSizer *bsz_ident = new wxBoxSizer( wxVERTICAL ) ;
   wxStaticText *stx_name
   = new wxStaticText( this, wxID_ANY, APP_DISPLAY_NAME ) ;
   stx_name->SetFont( wxFont( 25, wxFONTFAMILY_SWISS, wxFONTSTYLE_NORMAL,
                              wxFONTWEIGHT_BOLD
                            )
                    ) ;
   bsz_ident->Add( stx_name, 0, wxLEFT | wxRIGHT, 5 ) ;

   wxStaticText *stx_version
   = new wxStaticText( this, wxID_ANY, co_s_version ) ;
   stx_version->SetToolTip( wxString::Format( _( "Object type : %s" ),
                                              APP_BUILT_TYPE
                                            )
                          ) ;
   stx_version->SetFont( wxFont( 8, wxFONTFAMILY_SWISS, wxFONTSTYLE_NORMAL,
                                 wxFONTWEIGHT_NORMAL
                               )
                       ) ;
   bsz_ident->Add( stx_version, 0, wxLEFT | wxRIGHT, 5 ) ;

   wxStaticText *stx_copyright
   = new wxStaticText( this, wxID_ANY, APP_COPYRIGHT ) ;
   stx_copyright->SetFont( stx_version->GetFont() ) ;
   bsz_ident->Add( stx_copyright, 0, wxLEFT | wxRIGHT, 5 ) ;
   /*----------------------------------------------------------------------*/
   bsz_icon_ident->Add( bsz_ident, 0, wxALIGN_CENTER_VERTICAL, 5 ) ;
   bsz_gen->Add( bsz_icon_ident, 0, wxALL | wxEXPAND, 10 ) ;

   /*----------------------------------------------------------------------*/
   wxBoxSizer *bsz_detail = new wxBoxSizer( wxVERTICAL ) ;
   /*--( General Information )---------------------------------------------*/
   wxBoxSizer *bsz_info = new wxBoxSizer( wxVERTICAL ) ;

   bsz_info->Add( new wxStaticText( this, wxID_ANY,
                                    wxGetTranslation( APP_DESCRIPTION )
                                  ),
                  0, wxALIGN_CENTER_HORIZONTAL | wxLEFT | wxRIGHT, 5
                ) ;
   bsz_detail->Add( bsz_info, 0, wxEXPAND | wxBOTTOM | wxLEFT | wxRIGHT, 5 );

   /*--( Licence )---------------------------------------------------------*/
   wxBoxSizer *bsz_lic = new wxBoxSizer( wxHORIZONTAL ) ;
   bsz_lic->Add( new wxStaticText( this, wxID_ANY, _( "License :" ) ),
                 0, wxALIGN_CENTER_VERTICAL | wxLEFT | wxRIGHT, 5
               ) ;
   bsz_lic->Add( new wxGenericHyperlinkCtrl( this, wxID_ANY,
                                             wxGetTranslation( APP_LICENSE ),
                                             APP_LICENSE_URL
                                           ),
                 0, wxALIGN_CENTER_VERTICAL | wxRIGHT, 5
               ) ;
   bsz_detail->Add( bsz_lic, 0,
                    wxALIGN_CENTER_HORIZONTAL | wxLEFT | wxRIGHT, 5
                  ) ;

   /*----------------------------------------------------------------------*/
   wxStaticBoxSizer *stbsz_hl
                  = new wxStaticBoxSizer( wxVERTICAL, this ) ;
   wxFlexGridSizer *fgsz_hl = new wxFlexGridSizer( 2, 0, 0 ) ;
   fgsz_hl->AddGrowableCol( 1 ) ;
   /*----------------------------------------------------------------------*/
   fgsz_hl->Add( new wxStaticText( this, wxID_ANY, _( "Web site :" ) ),
                 0, wxALIGN_CENTER_VERTICAL | st_co_i_bf, 5
               ) ;
   fgsz_hl->Add( new wxGenericHyperlinkCtrl( this, wxID_ANY,
                                             APP_URL_SITE, APP_URL_SITE
                                           ),
                 0, wxALIGN_CENTER_VERTICAL | st_co_i_bf, 5
               ) ;
   /*----------------------------------------------------------------------*/
   fgsz_hl->Add( new wxStaticText( this, wxID_ANY, _( "Forum :" ) ),
                 0, wxALIGN_CENTER_VERTICAL | st_co_i_bf, 5
               ) ;
   fgsz_hl->Add( new wxGenericHyperlinkCtrl( this, wxID_ANY,
                                             APP_URL_FORUM, APP_URL_FORUM
                                           ),
                 0, wxALIGN_CENTER_VERTICAL | st_co_i_bf, 5
               ) ;
   /*----------------------------------------------------------------------*/
   {
      /*-------------------------------------------------------------------*/
      fgsz_hl->Add( new wxStaticText( this, wxID_ANY, _( "Remarks :" ) ),
                    0, wxALIGN_CENTER_VERTICAL | st_co_i_bf, 5
                  ) ;
      /*-------------------------------------------------------------------*/
      const wxString co_s_url
      =   wxString( "mailto:" ) + APP_MAIL
        + "?subject=" APP_DISPLAY_NAME_ASCII " "
        + co_s_version + " - " + wxGetOsDescription() ;
      /*-------------------------------------------------------------------*/
      wxGenericHyperlinkCtrl *hl
      = new wxGenericHyperlinkCtrl( this, wxID_ANY, APP_MAIL, co_s_url ) ;
      /*-------------------------------------------------------------------*/
      fgsz_hl->Add( hl, 0, wxALIGN_CENTER_VERTICAL | st_co_i_bf, 5 ) ;
      /*-------------------------------------------------------------------*/
   }
   /*----------------------------------------------------------------------*/
   {
      /*-------------------------------------------------------------------*/
      fgsz_hl->Add( new wxStaticText( this, wxID_ANY, _( "Translator :" ) ),
                    0, wxALIGN_CENTER_VERTICAL | st_co_i_bf, 5
                  ) ;
      /*-------------------------------------------------------------------*/
      wxString s_mail
             = wxTranslations::Get()->GetHeaderValue( "Language-Team" ) ;
      if( s_mail.empty() ) { s_mail = APP_MAIL_TRANSLATOR ; }
      /*-------------------------------------------------------------------*/
      const wxString co_s_url
      =   "mailto:" + s_mail + "?subject=Translation "
        + APP_DISPLAY_NAME_ASCII " " + co_s_version
        + " - " + wxGetOsDescription() ;
      /*-------------------------------------------------------------------*/
      wxGenericHyperlinkCtrl *hl
      = new wxGenericHyperlinkCtrl( this, wxID_ANY, s_mail, co_s_url ) ;
      /*-------------------------------------------------------------------*/
      fgsz_hl->Add( hl, 0, wxALIGN_CENTER_VERTICAL | st_co_i_bf, 5 ) ;
      /*-------------------------------------------------------------------*/
   }
   /*----------------------------------------------------------------------*/
   stbsz_hl->Add( fgsz_hl, 0, wxEXPAND ) ;

   bsz_detail->Add( stbsz_hl, 0, wxALL | wxEXPAND, 5 ) ;

   /*--( Credits )---------------------------------------------------------*/
   {
      /*-------------------------------------------------------------------*/
      wxStaticBoxSizer *stbsz_cred
      = new wxStaticBoxSizer( wxVERTICAL, this, _( "Credits" ) ) ;
      m_wsz_credits = new wxWrapSizer() ;
      /*--( Virtual function defined in CDlgAbout class )------------------*/
      fill_credits() ;
      /*-------------------------------------------------------------------*/
      stbsz_cred->Add( m_wsz_credits ) ;
      bsz_detail->Add( stbsz_cred, 1, wxALL | wxEXPAND, 5 ) ;
      /*-------------------------------------------------------------------*/
   }
   /*----------------------------------------------------------------------*/
   bsz_gen->Add( bsz_detail, 0, wxEXPAND, 5 ) ;
   /*----------------------------------------------------------------------*/
   wxButton *bt_ok = new wxButton( this, wxID_OK ) ;
   bt_ok->SetFocus() ;
   bt_ok->SetDefault() ;
   bsz_gen->Add( bt_ok, 0, wxALIGN_CENTER_HORIZONTAL | wxALL, 5 ) ;
   /*----------------------------------------------------------------------*/
   SetSizer( bsz_gen ) ;
   /*----------------------------------------------------------------------*/
   Layout() ;
   SetInitialSize() ;
   CentreOnParent() ;
   /*----------------------------------------------------------------------*/
}

/*-------------------------------------------------------------------------*/
int sc::CDlgAboutBase::get_modal()
{
   /*----------------------------------------------------------------------*/
   build_ui() ;
   return ShowModal() ;
   /*----------------------------------------------------------------------*/
}

/*-------------------------------------------------------------------------*/



/*==========================================================================+
!                        End of file sc_about.cpp                           !
+==========================================================================*/
